@@ -73,7 +73,9 @@
 					      riece-server-name)
 			 (riece-make-identity (car targets)
 					      riece-server-name)
-			 message))))
+			 message nil
+			 (riece-identity-equal-no-server
+			  user riece-real-nickname)))))
 
 (defun riece-handle-notice-message (prefix string)
   (let* ((user (if prefix
@@ -87,7 +89,9 @@
 						  riece-server-name)
 			     (riece-make-identity (car targets)
 						  riece-server-name)
-			     message 'notice))
+			     message 'notice
+			     (riece-identity-equal-no-server
+			      user riece-real-nickname)))
       ;; message from server
       (riece-insert-notice
        (list riece-dialogue-buffer riece-others-buffer)
@@ -107,6 +111,9 @@
 	 (user-identity (riece-make-identity user riece-server-name)))
     (while channels
       (riece-naming-assert-join user (car channels))
+      (if (and riece-gather-channel-modes
+	       (riece-identity-equal-no-server user riece-real-nickname))
+	  (riece-send-string (format "MODE %s\r\n" (car channels))))
       (let* ((channel-identity (riece-make-identity (car channels)
 						    riece-server-name))
 	     (buffer (riece-channel-buffer channel-identity)))
